@@ -43,6 +43,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   ## (1) Check arguments
   ##
   ##
+  chknull(sm)
   chklevel(level)
   chklevel(level.comb)
   chklogical(comb.fixed)
@@ -64,7 +65,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
   ## Additional arguments / checks for metacont objects
   ##
   fun <- "metacont"
-  sm <- setchar(sm, c("MD", "SMD", "ROM"))
+  sm <- setchar(sm, .settings$sm4cont)
   chklogical(pooledvar)
   method.smd <- setchar(method.smd, c("Hedges", "Cohen", "Glass"))
   sd.glass <- setchar(sd.glass, c("control", "experimental"))
