@@ -4,33 +4,37 @@ metareg <- function(x, formula,
                     level.comb = x$level.comb,
                     intercept = TRUE,
                     ...) {
-  
+
   if ("data" %in% names(list(...))) {
-    warning("Please note, argument 'data' has been renamed to 'x' in version 3.0-0 of R package meta (see help page of R function metareg). No meta-regression conducted.")
+    warning("Please note, argument 'data' has been renamed to 'x' ",
+            "in version 3.0-0 of R package meta ",
+            "(see help page of R function metareg). ",
+            "No meta-regression conducted.")
     return(invisible(NULL))
   }
-  
+
   if (is.call(x)) {
-    warning("Please note, first two arguments of R function metareg have been interchanged in version 3.0-0 of R package meta. No meta-regression conducted.")
+    warning("Please note, first two arguments of R function metareg ",
+            "have been interchanged in version 3.0-0 of R package meta. ",
+            "No meta-regression conducted.")
     return(invisible(NULL))
   }
-  
-  
+
+
   ##
   ##
   ## (1) Check for meta object
   ##
   ##
   chkclass(x, "meta")
-  
-  
+
+
   ##
   ## Check whether R package metafor is installed
   ##
-  is.installed.package("metafor", "metareg",
-                       version = .settings$metafor)
-  
-  
+  is.installed.package("metafor", "metareg", version = .settings$metafor)
+
+
   ##
   ## Assignments
   ##
@@ -65,27 +69,33 @@ metareg <- function(x, formula,
     event <- x$event
     time <- x$time
   }
-  
-  
-  if (missing(formula))
+
+
+  if (missing(formula)) {
     if (!is.null(x$data$.byvar))
       if (intercept)
         formula <- as.call(~ .byvar)
       else
         formula <- as.call(~ .byvar - 1)
-        
     else {
-      warning("No meta-regression conducted as argument 'formula' is missing and no information is provided on subgroup variable, i.e. list element 'byvar' in meta-analysis object 'x' (see help page of R function metareg).")
+      warning("No meta-regression conducted as argument 'formula' ",
+              "is missing and no information is provided on subgroup ",
+              "variable, i.e. list element 'byvar' in meta-analysis object ",
+              "'x' (see help page of R function metareg).")
       return(invisible(NULL))
     }
+  }
   else {
     formula.text <- deparse(substitute(formula))
     formula.text <- gsub("~", "", formula.text)
     formula.text <- gsub("\\\"", "", formula.text)
     formula.text <- gsub("\\\'", "", formula.text)
+    if (!intercept)
+      formula.text <- paste0(formula.text, " - 1")
     formula <- as.formula(paste("~", formula.text))
   }
-  
+
+
   if (is.null(method.tau))
     method.tau <- "DL"
   ##
@@ -93,7 +103,8 @@ metareg <- function(x, formula,
                         c("DL", "PM", "REML", "ML", "HS", "SJ", "HE", "EB", "FE"))
   ##
   if (method.tau == "PM") {
-    warning("Meta-regresion method not available for method.tau = \"PM\". Using REML method instead (method.tau = \"REML\").")
+    warning("Meta-regresion method not available for method.tau = \"PM\". ",
+            "Using REML method instead (method.tau = \"REML\").")
     method.tau <- "REML"
   }
   ##
@@ -101,46 +112,48 @@ metareg <- function(x, formula,
   ##
   chklevel(level.comb)
   chklogical(intercept)
-  
+
   if (is.null(x$data)) {
-    warning("Necessary data not available. Please, recreate meta-analysis object without option 'keepdata = FALSE'.")
+    warning("Necessary data not available. Please, recreate meta-analysis ",
+            "object without option 'keepdata = FALSE'.")
     return(invisible(NULL))
   }
-  
-  
+
+
   ##
   ## Use subset of studies in meta-regression
-  ##  
+  ##
   if (!is.null(x$subset))
     dataset <- x$data[x$subset, ]
   else
     dataset <- x$data
-  
-  
+
+
   ##
   ## Exclude studies from meta-regression
-  ## 
+  ##
   if (!is.null(x$exclude)) {
     exclude <- dataset$.exclude
     dataset <- dataset[!dataset$.exclude, ]
   }
   else
     exclude <- rep(FALSE, nrow(dataset))
-  
-  
+
+
   ##
   ## Argument test in rma.uni() and rma.glmm()
   ##
   test <- ifelse(!hakn, "z",
                  ifelse(method != "GLMM", "knha", "t"))
-  
+
   ##
   ## Covariate 'x' make problems without removing meta-analysis object x
   ##
   ..x <- x
   rm(x)
   ##
-  warn.FE <- "Fallback to fixed effect model (argument method.tau = \"FE\") due to small number of studies."
+  warn.FE <- paste("Fallback to fixed effect model (argument",
+                   "method.tau = \"FE\") due to small number of studies.")
   ##
   if (method != "GLMM")
     res <- metafor::rma.uni(yi = TE[!exclude],
@@ -173,8 +186,10 @@ metareg <- function(x, formula,
     }
     else if (metainc) {
       if (sum(!exclude) > 2)
-        res <- metafor::rma.glmm(x1i = event.e[!exclude], t1i = time.e[!exclude],
-                                 x2i = event.c[!exclude], t2i = time.c[!exclude],
+        res <- metafor::rma.glmm(x1i = event.e[!exclude],
+                                 t1i = time.e[!exclude],
+                                 x2i = event.c[!exclude],
+                                 t2i = time.c[!exclude],
                                  data = dataset,
                                  mods = formula, method = method.tau,
                                  test = test, level = 100 * level.comb,
@@ -183,8 +198,10 @@ metareg <- function(x, formula,
       else {
         if (method.tau != "FE")
           warning(warn.FE)
-        res <- metafor::rma.glmm(x1i = event.e[!exclude], t1i = time.e[!exclude],
-                                 x2i = event.c[!exclude], t2i = time.c[!exclude],
+        res <- metafor::rma.glmm(x1i = event.e[!exclude],
+                                 t1i = time.e[!exclude],
+                                 x2i = event.c[!exclude],
+                                 t2i = time.c[!exclude],
                                  data = dataset,
                                  mods = formula, method = "FE",
                                  test = test, level = 100 * level.comb,
@@ -231,8 +248,8 @@ metareg <- function(x, formula,
       }
     }
   }
-  
-  
+
+
   res$.meta <- list(x = ..x,
                     formula = formula,
                     method.tau = method.tau,
@@ -245,6 +262,6 @@ metareg <- function(x, formula,
                     version.metafor = packageDescription("metafor")$Version)
 
   class(res) <- c("metareg", class(res))
-  
+
   res
 }
