@@ -4,7 +4,9 @@ settings.meta <- function(...) {
   ##
   res <- .settings
   res$metafor <- NULL
-  res$sm4cor <- res$sm4prop <- res$sm4rate <- NULL
+  res$sm4bin <- res$sm4cont <- res$sm4cor <- res$sm4inc <-
+    res$sm4mean <- res$sm4prop <- res$sm4rate <- NULL
+  res$ci4prop <- NULL
   res$argslist <- NULL
   
   
@@ -44,7 +46,7 @@ settings.meta <- function(...) {
                           previous = c("Previous value",
                                        "--------------",
                                        label.old[sel]))
-
+      
       names(tdata) <- c("--------", "", "---------",
                         "", "--------------")
       ##
@@ -160,43 +162,44 @@ settings.meta <- function(...) {
               utils::packageDescription("meta")$Version, ") **\n\n", sep = ""))
     ##
     cat("* General settings *\n", sep = "")
-    catarg("level        ")
-    catarg("level.comb   ")
-    catarg("comb.fixed   ")
-    catarg("comb.random  ")
-    catarg("hakn         ")
-    catarg("method.tau   ")
-    catarg("tau.common   ")
-    catarg("prediction   ")
-    catarg("level.predict")
-    catarg("method.bias  ")
-    catarg("title        ")
-    catarg("complab      ")
-    catarg("CIbracket    ")
-    catarg("CIseparator  ")
-    catarg("print.byvar  ")
-    catarg("byseparator  ")
-    catarg("keepdata     ")
-    catarg("warn         ")
-    catarg("backtransf   ")
-    catarg("digits       ")
-    catarg("digits.se    ")
-    catarg("digits.zval  ")
-    catarg("digits.Q     ")
-    catarg("digits.tau2  ")
-    catarg("digits.H     ")
-    catarg("digits.I2    ")
-    catarg("digits.prop  ")
-    catarg("digits.weight")
-    catarg("digits.pval  ")
-    catarg("digits.pval.Q")
+    catarg("level          ")
+    catarg("level.comb     ")
+    catarg("comb.fixed     ")
+    catarg("comb.random    ")
+    catarg("hakn           ")
+    catarg("method.tau     ")
+    catarg("tau.common     ")
+    catarg("prediction     ")
+    catarg("level.predict  ")
+    catarg("method.bias    ")
+    catarg("title          ")
+    catarg("complab        ")
+    catarg("CIbracket      ")
+    catarg("CIseparator    ")
+    catarg("print.byvar    ")
+    catarg("byseparator    ")
+    catarg("keepdata       ")
+    catarg("warn           ")
+    catarg("backtransf     ")
+    catarg("digits         ")
+    catarg("digits.se      ")
+    catarg("digits.zval    ")
+    catarg("digits.Q       ")
+    catarg("digits.tau2    ")
+    catarg("digits.H       ")
+    catarg("digits.I2      ")
+    catarg("digits.prop    ")
+    catarg("digits.weight  ")
+    catarg("digits.pval    ")
+    catarg("digits.pval.Q  ")
     catarg("scientific.pval")
-    catarg("print.I2")
-    catarg("print.H")
-    catarg("print.Rb")
-    catarg("text.tau2")
-    catarg("text.I2")
-    catarg("text.Rb")
+    catarg("big.mark       ")
+    catarg("print.I2       ")
+    catarg("print.H        ")
+    catarg("print.Rb       ")
+    catarg("text.tau2      ")
+    catarg("text.I2        ")
+    catarg("text.Rb        ")
     ##
     cat("\n* Default summary measure (argument 'sm' in corresponding function) *\n")
     cat("- metabin():  ")
@@ -207,6 +210,8 @@ settings.meta <- function(...) {
     catarg("smcor ", newline = FALSE)
     cat("- metainc():  ")
     catarg("sminc ", newline = FALSE)
+    cat("- metamean(): ")
+    catarg("smmean", newline = FALSE)
     cat("- metaprop(): ")
     catarg("smprop", newline = FALSE)
     cat("- metarate(): ")
@@ -282,6 +287,7 @@ settings.meta <- function(...) {
     setOption("digits.pval", 4)
     setOption("digits.pval.Q", 4)
     setOption("scientific.pval", FALSE)
+    setOption("big.mark", "")
     setOption("print.I2", TRUE)
     setOption("print.H", TRUE)
     setOption("print.Rb", FALSE)
@@ -303,6 +309,7 @@ settings.meta <- function(...) {
     setOption("smcont", "MD")
     setOption("smcor", "ZCOR")
     setOption("sminc", "IRR")
+    setOption("smmean", "MRAW")
     setOption("smprop", "PLOGIT")
     setOption("smrate", "IRLN")
     ##
@@ -411,6 +418,7 @@ settings.meta <- function(...) {
     iddigits.pval <- argid(names, "digits.pval")
     iddigits.pval.Q <- argid(names, "digits.pval.Q")
     idscientific.pval <- argid(names, "scientific.pval")
+    idbig.mark <- argid(names, "big.mark")
     idprint.I2 <- argid(names, "print.I2")
     idprint.H <- argid(names, "print.H")
     idprint.Rb <- argid(names, "print.Rb")
@@ -432,6 +440,7 @@ settings.meta <- function(...) {
     idsmcont <- argid(names, "smcont")
     idsmcor <- argid(names, "smcor")
     idsminc <- argid(names, "sminc")
+    idsmmean <- argid(names, "smmean")
     idsmprop <- argid(names, "smprop")
     idsmrate <- argid(names, "smrate")
     ##
@@ -507,7 +516,7 @@ settings.meta <- function(...) {
     if (!is.na(idmethod.bias)) {
       method.bias <- args[[idmethod.bias]]
       method.bias <- setchar(method.bias,
-                            c("rank", "linreg", "mm", "count", "score", "peters"))
+                             c("rank", "linreg", "mm", "count", "score", "peters"))
       setOption("method.bias", method.bias)
     }
     if (!is.na(idtitle)) {
@@ -527,7 +536,7 @@ settings.meta <- function(...) {
     if (!is.na(idCIbracket)) {
       CIbracket <- args[[idCIbracket]]
       CIbracket <- setchar(CIbracket,
-                            c("[", "(", "{", ""))
+                           c("[", "(", "{", ""))
       setOption("CIbracket", CIbracket)
     }
     if (!is.na(idCIseparator)) {
@@ -624,6 +633,13 @@ settings.meta <- function(...) {
       chklogical(scientific.pval)
       setOption("scientific.pval", scientific.pval)
     }
+    if (!is.na(idbig.mark)) {
+      big.mark <- args[[idbig.mark]]
+      if (length(big.mark) != 1)
+        stop("Argument 'big.mark' must be a character string.")
+      ##
+      setOption("big.mark", big.mark)
+    }
     if (!is.na(idprint.I2)) {
       print.I2 <- args[[idprint.I2]]
       chklogical(print.I2)
@@ -665,7 +681,7 @@ settings.meta <- function(...) {
     ##
     if (!is.na(idsmbin)) {
       smbin <- args[[idsmbin]]
-      smbin <- setchar(smbin, c("OR", "RD", "RR", "ASD"))
+      smbin <- setchar(smbin, .settings$sm4bin)
       setOption("smbin", smbin)
     }
     if (!is.na(idmethod)) {
@@ -691,7 +707,7 @@ settings.meta <- function(...) {
       incr <- args[[idincr]]
       if (!is.numeric(incr))
         incr <- setchar(incr, "TACC",
-                       "should be numeric or the character string \"TACC\"")
+                        "should be numeric or the character string \"TACC\"")
       setOption("incr", incr)
     }
     if (!is.na(idallincr)) {
@@ -729,7 +745,7 @@ settings.meta <- function(...) {
     ##
     if (!is.na(idsmcont)) {
       smcont <- args[[idsmcont]]
-      smcont <- setchar(smcont, c("MD", "SMD", "ROM"))
+      smcont <- setchar(smcont, .settings$sm4cont)
       setOption("smcont", smcont)
     }
     ##
@@ -741,14 +757,6 @@ settings.meta <- function(...) {
       setOption("smcor", smcor)
     }
     ##
-    ## R function metainc
-    ##
-    if (!is.na(idsminc)) {
-      sminc <- args[[idsminc]]
-      sminc <- setchar(sminc, c("IRR", "IRD"))
-      setOption("sminc", sminc)
-    }
-    ##
     ## R function metacont
     ##
     if (!is.na(idpooledvar)) {
@@ -772,6 +780,22 @@ settings.meta <- function(...) {
       setOption("exact.smd", exact.smd)
     }
     ##
+    ## R function metainc
+    ##
+    if (!is.na(idsminc)) {
+      sminc <- args[[idsminc]]
+      sminc <- setchar(sminc, .settings$sm4inc)
+      setOption("sminc", sminc)
+    }
+    ##
+    ## R function metamean
+    ##
+    if (!is.na(idsmmean)) {
+      smmean <- args[[idsmmean]]
+      smmean <- setchar(smmean, .settings$sm4mean)
+      setOption("smmean", smmean)
+    }
+    ##
     ## R function metaprop
     ##
     if (!is.na(idsmprop)) {
@@ -782,8 +806,7 @@ settings.meta <- function(...) {
     ##
     if (!is.na(idmethod.ci)) {
       method.ci <- args[[idmethod.ci]]
-      method.ci <- setchar(method.ci,
-                          c("CP", "WS", "WSCC", "AC", "SA", "SACC", "NAsm"))
+      method.ci <- setchar(method.ci, .settings$ci4prop)
       setOption("method.ci", method.ci)
     }
     ##
